/* MSPDebug - debugging tool for MSP430 MCUs
 * Copyright (C) 2009-2013 Daniel Beer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef BSLHID_H_
#define BSLHID_H_

#include "transport.h"

/* Open a USB HID device used to wrap the USB bootstrap loader serial
 * protocol. The interface is described in SLAU319C: "MSP430 Programming
 * via the Bootstrap Loader".
 */
#if defined(__APPLE__)
transport_t bslosx_open(const char *dev_path, const char *requested_serial);
#else
transport_t bslhid_open(const char *dev_path, const char *requested_serial);
#endif

#endif
